package
Version:
v0.0.0-...-07862d9
Opens a new window with list of versions in this module.
Published: Jun 3, 2024
License: Apache-2.0
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Auth struct {
SecretKey string `env:"AUTH_SECRET,required"`
}
type DB struct {
DSN string `env:"DATABASE_URL,required"`
}
type Server struct {
Port int `env:"PORT" envDefault:"8080"`
RedirectMode bool `env:"REDIRECT_MODE" envDefault:"false"`
}
type Smtp struct {
From string `env:"SMTP_FROM,required"`
Password string `env:"SMTP_PASSWORD,required"`
Host string `env:"SMTP_HOST,required"`
Port int `env:"SMTP_PORT" envDefault:"587"`
WebAddressRedirect string `env:"SMTP_WEB_REDIRECT_URL" envDefault:"http://localhost:3000"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.